==> verovio-3.8.0.tar.gz: verovio-3.8.0/include/vrv/multirest.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        multirest.h
// Author:      Rodolfo Zitellini
// Created:     2013
// Copyright (c) Authors and others. All rights reserved.
/////////////////////////////////////////////////////////////////////////////

#ifndef __VRV_MULTIREST_H__
#define __VRV_MULTIREST_H__

#include "atts_cmn.h"
#include "atts_shared.h"
#include "atts_visual.h"
#include "layerelement.h"
#include "positioninterface.h"

namespace vrv {

//----------------------------------------------------------------------------
// MultiRest
//----------------------------------------------------------------------------

/**
 * This class models the MEI <multiRest> element.
 */
class MultiRest : public LayerElement,
                  public PositionInterface,
                  public AttColor,
                  public AttMultiRestVis,
                  public AttNumbered,
                  public AttNumberPlacement,
                  public AttWidth {
public:
    /**
     * @name Constructors, destructors, reset and class name methods
     * Reset method resets all attribute classes
     */
    ///@{
    MultiRest();
    virtual ~MultiRest();
    Object *Clone() const override { return new MultiRest(*this); }
    void Reset() override;
    std::string GetClassName() const override { return "MultiRest"; }
    ///@}

    /**
     * True if block style rendering applies
     */
    bool UseBlockStyle(Doc *doc) const;

private:
    //
public:
    //
private:
};

} // namespace vrv

#endif

==> verovio-3.15.0.tar.gz: verovio-3.15.0/include/vrv/multirest.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        multirest.h
// Author:      Rodolfo Zitellini
// Created:     2013
// Copyright (c) Authors and others. All rights reserved.
/////////////////////////////////////////////////////////////////////////////

#ifndef __VRV_MULTIREST_H__
#define __VRV_MULTIREST_H__

#include "atts_cmn.h"
#include "atts_shared.h"
#include "atts_visual.h"
#include "layerelement.h"
#include "positioninterface.h"

namespace vrv {

//----------------------------------------------------------------------------
// MultiRest
//----------------------------------------------------------------------------

/**
 * This class models the MEI <multiRest> element.
 */
class MultiRest : public LayerElement,
                  public PositionInterface,
                  public AttColor,
                  public AttMultiRestVis,
                  public AttNumbered,
                  public AttNumberPlacement,
                  public AttWidth {
public:
    /**
     * @name Constructors, destructors, reset and class name methods
     * Reset method resets all attribute classes
     */
    ///@{
    MultiRest();
    virtual ~MultiRest();
    Object *Clone() const override { return new MultiRest(*this); }
    void Reset() override;
    std::string GetClassName() const override { return "MultiRest"; }
    ///@}

    /**
     * True if block style rendering applies
     */
    bool UseBlockStyle(const Doc *doc) const;

private:
    //
public:
    //
private:
};

} // namespace vrv

#endif
